polyfemos.scripts.sohemailer — polyfemos 0.3.29 documentation

# polyfemos.scripts.sohemailer

A script for sending state of health alerts via email

The script may be run for example using cron to check and notify about the active alerts daily. See more information in State of health emailer.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.scripts.sohemailer.` `main`(argv=None)
  Parameters

    argv (list) – command line arguments

`polyfemos.scripts.sohemailer.` `send_email`(from_='', to_='', passwd='', subject='', content='')

  Send email using ‘smtp.gmail.com’ smtp server.

  Parameters

    - from_ (str) – email address of the sender

    - to_ (list[str]) – list of email address of recipients

    - passwd (str) – sender email account password

    - subject (str) – email subject

    - content (str) – message contents